import Vue from 'vue'
import Router from 'vue-router'

Vue.use(Router)

/* Layout */
import Layout from '@/layout'
/**
 * Note: sub-menu only appear when route children.length >= 1
 * Detail see: https://panjiachen.github.io/vue-element-admin-site/guide/essentials/router-and-nav.html
 *
 * hidden: true                   if set true, item will not show in the sidebar(default is false)
 * alwaysShow: true               if set true, will always show the root menu
 *                                if not set alwaysShow, when item has more than one children route,
 *                                it will becomes nested mode, otherwise not show the root menu
 * redirect: noRedirect           if set noRedirect will no redirect in the breadcrumb
 * name:'router-name'             the name is used by <keep-alive> (must set!!!)
 * meta : {
    roles: ['admin','editor']    control the page roles (you can set multiple roles)
    title: 'title'               the name show in sidebar and breadcrumb (recommend set)
    icon: 'svg-name'/'el-icon-x' the icon show in the sidebar
    breadcrumb: false            if set false, the item will hidden in breadcrumb(default is true)
    activeMenu: '/example/list'  if set path, the sidebar will highlight the path you set
  }
 */

/**
 * constantRoutes
 * a base page that does not have permission requirements
 * all roles can be accessed
 */
export const constantRoutes = [
  {
    path: '/',
    component: Layout,
    redirect: '/dashboard',
    children: [{
      path: 'dashboard',
      name: 'Dashboard',
      component: () => import('@/views/dashboard/index'),
      meta: { title: '工作台', icon: 'dashboard' }
    }]
  },

  // 学员管理
  {
    path: '/students',
    component: Layout,
    meta: { title: '学员管理', icon: 'form' },
    children: [
      {
        path: 'schoolTerm',
        name: '学期列表',
        component: () => import('@/views/students/schoolTerm/list'),
        meta: { title: '学期列表', icon: 'schoolTerm' }
      },
      {
        hidden: true,
        path: 'schoolTerm/edit',
        name: 'schoolTermEdit',
        component: () => import('@/views/students/schoolTerm/edit'),
        meta: { title: '学期编辑', icon: 'question' }
      },
      {
        path: 'schoolClass',
        name: '班级列表',
        component: () => import('@/views/students/schoolClass/list'),
        meta: { title: '班级列表', icon: 'schoolClass' }
      },
      {
        hidden: true,
        path: 'schoolClass/edit',
        name: 'schoolClassEdit',
        component: () => import('@/views/students/schoolClass/edit'),
        meta: { title: '班级编辑', icon: 'question' }
      },
      {
        path: 'sutdentsList',
        name: '学员列表',
        component: () => import('@/views/students/studentsList'),
        meta: { title: '学员列表', icon: 'student' }
      },
      {
        hidden: true,
        path: 'students/detail',
        name: 'studentDetail',
        component: () => import('@/views/students/studentDetail'),
        meta: { title: '学员详情', icon: 'question' }
      }
    ]
  },

  // 课程管理
  {
    path: '/course',
    component: Layout,
    meta: { title: '课程管理', icon: 'course' },
    children: [
      {
        path: 'course',
        name: '课程列表',
        component: () => import('@/views/course/index'),
        meta: { title: '课程列表', icon: 'course' }
      },
      {
        hidden: true,
        path: 'course/edit',
        name: 'courseEdit',
        component: () => import('@/views/course/edit'),
        meta: { title: '课程编辑', icon: 'question' }
      }
    ]
  },

  // 签到管理
  {
    path: '/signIn',
    component: Layout,
    meta: { title: '签到管理', icon: 'signIn' },
    children: [
      {
        path: 'signIn',
        name: '签到列表',
        component: () => import('@/views/signIn/index'),
        meta: { title: '签到列表', icon: 'signIn' }
      },
      {
        hidden: true,
        path: 'signIn/edit',
        name: 'signInEdit',
        component: () => import('@/views/signIn/edit'),
        meta: { title: '签到编辑', icon: 'question' }
      }
    ]
  },

  // 轮播图
  {
    path: '/banners',
    component: Layout,
    meta: { title: '轮播图管理', icon: 'banner' },
    children: [
      {
        path: 'banners',
        name: '轮播图列表',
        component: () => import('@/views/banners/index'),
        meta: { title: '轮播图列表', icon: 'banner' }
      },
      {
        hidden: true,
        path: 'banners/edit',
        name: 'bannersEdit',
        component: () => import('@/views/banners/edit'),
        meta: { title: '轮播图编辑', icon: 'question' }
      }
    ]
  },

  // 照片墙
  {
    path: '/photoWall',
    component: Layout,
    meta: { title: '照片墙', icon: 'form' },
    children: [
      {
        path: 'photoWall',
        name: '照片列表',
        component: () => import('@/views/photoWall/index'),
        meta: { title: '照片墙', icon: 'photoWall' }
      }
    ]
  },

  // 问卷调查
  {
    path: '/questionnaire',
    component: Layout,
    meta: { title: '问卷调查', icon: 'form' },
    children: [
      {
        path: 'questionnaire',
        name: '问卷列表',
        component: () => import('@/views/questionnaire/index'),
        meta: { title: '问卷列表', icon: 'questionnaire' }
      },
      {
        hidden: true,
        path: 'questionnaire/edit',
        name: 'questionnaireEdit',
        component: () => import('@/views/questionnaire/edit'),
        meta: { title: '问卷编辑', icon: 'question' }
      }
    ]
  },
  {
    path: '/login',
    component: () => import('@/views/login/index'),
    hidden: true
  },

  {
    path: '/404',
    component: () => import('@/views/404'),
    hidden: true
  },

  // 404 page must be placed at the end !!!
  { path: '*', redirect: '/404', hidden: true }
]

const createRouter = () => new Router({
  // mode: 'history', // require service support
  scrollBehavior: () => ({ y: 0 }),
  routes: constantRoutes
})

const router = createRouter()

// Detail see: https://github.com/vuejs/vue-router/issues/1234#issuecomment-357941465
export function resetRouter() {
  const newRouter = createRouter()
  router.matcher = newRouter.matcher // reset router
}

export default router
